==> moodle-3.4.4.zip: moodle/user/profile/field/textarea/lang/en/profilefield_textarea.php <==
<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'profilefield_textarea', language 'en', branch 'MOODLE_20_STABLE'
 *
 * @package   profilefield_textarea
 * @copyright 1999 onwards Martin Dougiamas  {@link http://moodle.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['pluginname'] = 'Text area';
$string['privacy:metadata:profile_field_textarea:userid'] = 'The ID of the user which data is stored by the Text area plugin.';
$string['privacy:metadata:profile_field_textarea:fieldid'] = 'The ID of the profile field.';
$string['privacy:metadata:profile_field_textarea:data'] = 'The stored user data.';
$string['privacy:metadata:profile_field_textarea:dataformat'] = 'The format of the stored user data.';
$string['privacy:metadata:profile_field_textarea:tableexplanation'] = 'Additional user information is stored here.';

==> moodle-3.11.2.zip: moodle/user/profile/field/textarea/lang/en/profilefield_textarea.php <==
<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'profilefield_textarea', language 'en', branch 'MOODLE_20_STABLE'
 *
 * @package   profilefield_textarea
 * @copyright 1999 onwards Martin Dougiamas  {@link http://moodle.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['pluginname'] = 'Text area';
$string['privacy:metadata:profile_field_textarea:userid'] = 'The ID of the user whose data is stored by the Text area user profile field';
$string['privacy:metadata:profile_field_textarea:fieldid'] = 'The ID of the profile field';
$string['privacy:metadata:profile_field_textarea:data'] = 'Text area user profile field user data';
$string['privacy:metadata:profile_field_textarea:dataformat'] = 'The format of Text area user profile field user data';
$string['privacy:metadata:profile_field_textarea:tableexplanation'] = 'Additional profile data';
